mstats count(db_service_calls_total) as count by biz_system,servicetype| fields biz_system,servicetype| eval targettype = concat("database_", substr(servicetype, 4))
mstats count(service_requests_total) as count by service, biz_system| fields service, biz_system
mstats count(messaging_service_produce_total) as count by biz_system,servicetype,service,host,port| fields biz_system,servicetype,service,host,port| eval targettype = substr(servicetype, 11)
mstats  avg('service_requests_failed_total'  ( 'service' in("keta-web") )) as 'avg(服务请求错误数  ( service in("keta-web") ))' by 'service' | eval _time = 0 | compare timeshift="-5m" type="stats"         | where periods=1          | eval 'avg(服务请求错误数  ( service in("keta-web") ))_ratio' = 'avg(服务请求错误数  ( service in("keta-web") ))_ratio'*100        | fields _time, service, 'avg(服务请求错误数  ( service in("keta-web") ))_ratio'
mstats  avg('service_requests_failed_total'  ( 'service' in("keta-data") )) as 'avg(服务请求错误数  ( service in("keta-data") ))' by 'service' | eval _time = 0 | compare timeshift="-5m" type="stats"         | where periods=1          | eval 'avg(服务请求错误数  ( service in("keta-data") ))_ratio' = 'avg(服务请求错误数  ( service in("keta-data") ))_ratio'*100        | fields _time, service, 'avg(服务请求错误数  ( service in("keta-data") ))_ratio'
mstats  avg('service_instance_requests_failed_total'  ( 'env' in("ketaops-1xx") ) AND ( 'instance' in("ketaops-1xx/keta-web-10-0-1-47") ) AND ( 'service' in("keta-web") )) as 'avg(实例请求错误数  ( env in("ketaops-1xx") ) AND ( instance in("ketaops-1xx/keta-web-10-0-1-47") ) AND ( service in("keta-web") ))' by 'env','instance','service' | eval _time = 0 | compare timeshift="-30m" type="stats"         | where periods=1          | eval 'avg(实例请求错误数  ( env in("ketaops-1xx") ) AND ( instance in("ketaops-1xx/keta-web-10-0-1-47") ) AND ( service in("keta-web") ))_ratio' = 'avg(实例请求错误数  ( env in("ketaops-1xx") ) AND ( instance in("ketaops-1xx/keta-web-10-0-1-47") ) AND ( service in("keta-web") ))_ratio'*100        | fields _time, env, instance, service, 'avg(实例请求错误数  ( env in("ketaops-1xx") ) AND ( instance in("ketaops-1xx/keta-web-10-0-1-47") ) AND ( service in("keta-web") ))_ratio'
mstats  avg('service_instance_requests_failed_total'  ( 'env' in("ketaops-1xx") ) AND ( 'instance' in("ketaops-1xx/neuralert-api-1") ) AND ( 'service' in("neuralert-api"))) as 'avg(实例请求错误数  ( env in("ketaops-1xx") ) AND ( instance in("ketaops-1xx/neuralert-api-1") ) AND ( service in("neuralert-api") ))' by 'env','instance','service' | eval _time = 0 | compare timeshift="-30m" type="stats"         | where periods=1          | eval 'avg(实例请求错误数  ( env in("ketaops-1xx") ) AND ( instance in("ketaops-1xx/neuralert-api-1") )AND ( service in("neuralert-api") ))_ratio' = 'avg(实例请求错误数  ( env in("ketaops-1xx") ) AND ( instance in("ketaops-1xx/neuralert-api-1") ) AND ( service in("neuralert-api") ))_ratio'*100        | fields _time, env, instance, service, 'avg(实例请求错误数  ( env in("ketaops-1xx") ) AND ( instance in("ketaops-1xx/neuralert-api-1") ) AND ( service in("neuralert-api") ))_ratio'
mstats  avg('service_instance_requests_failed_total'  ( 'env' in("benchmark") ) AND ( 'instance' in("ketadb/keta-web-10-0-1-47") ) AND ( 'service' in("ketadb") )) as 'avg(实例请求错误数  ( env in("benchmark") ) AND ( instance in("ketadb/keta-web-10-0-1-47") ) AND ( service in("ketadb") ))' by 'env','instance','service' | eval _time = 0 | compare timeshift="-30m" type="stats"         | where periods=1          | eval 'avg(实例请求错误数  ( env in("benchmark") ) AND ( instance in("ketadb/keta-web-10-0-1-47") ) AND ( service in("ketadb") ))_ratio' = 'avg(实例请求错误数  ( env in("benchmark") ) AND ( instance in("ketadb/keta-web-10-0-1-47") ) AND ( service in("ketadb") ))_ratio'*100        | fields _time, env, instance, service, 'avg(实例请求错误数  ( env in("benchmark") ) AND ( instance in("ketadb/keta-web-10-0-1-47") ) AND ( service in("ketadb") ))_ratio'
mstats  avg('service_instance_requests_failed_total'  ( 'env' in("benchmark") ) AND ( 'instance' in("ketadb/keta-data-10-0-1-246") ) AND ( 'service' in("ketadb") )) as 'avg(实例请求错误数  ( env in("benchmark") ) AND ( instance in("ketadb/keta-data-10-0-1-246") ) AND ( service in("ketadb") ))' by 'env','instance','service' | eval _time = 0 | compare timeshift="-30m" type="stats"         | where periods=1          | eval 'avg(实例请求错误数  ( env in("benchmark") ) AND ( instance in("ketadb/keta-data-10-0-1-246") ) AND ( service in("ketadb") ))_ratio' = 'avg(实例请求错误数  ( env in("benchmark") ) AND ( instance in("ketadb/keta-data-10-0-1-246") ) AND ( service in("ketadb") ))_ratio'*100        | fields _time, env, instance, service, 'avg(实例请求错误数  ( env in("benchmark") ) AND ( instance in("ketadb/keta-data-10-0-1-246") ) AND ( service in("ketadb") ))_ratio'
mstats  avg('container_memory_usage_pct'  ( 'host' in("rd1-0004") )) as 'avg(Container 内存使用百分比  ( host in("rd1-0004") ))' by container_id | eval _time = 0 | compare timeshift="-5m" type="stats"         | where periods=1          | eval 'avg(Container 内存使用百分比  ( host in("rd1-0004") ))_ratio' = 'avg(Container 内存使用百分比  ( host in("rd1-0004") ))_ratio'*100        | fields _time, container_id, 'avg(Container 内存使用百分比  ( host in("rd1-0004") ))_ratio'
mstats  avg('container_network_rx_errors'  ( 'host' in("10-0-1-64") )) as 'avg(Container 网络接收错误数  ( host in("10-0-1-64") ))' by 'container_id' | eval _time = 0
mstats span="1m" sumRate('host_diskio_write_ms') as 'sumRate(主机磁盘IO写入耗时(毫秒))' by 'host','host_ip'| compare timeshift="-1m" type="stats"         | where periods=1          | eval 'sumRate(主机磁盘IO写入耗时(毫秒))_ratio' = 'sumRate(主机磁盘IO写入耗时(毫秒))_ratio'*100        | fields _time, host, host_ip, 'sumRate(主机磁盘IO写入耗时(毫秒))_ratio'